import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisCheckBox extends StatelessWidget {
  final ValueChanged<dynamic> onChanged;
  final bool disabled;
  final bool value;
  final bool checkBoxAtEnd;
  final String label;
  final Widget? suffix;
  final Widget? labelWidget;
  final Color activeColor;
  final EdgeInsetsGeometry? padding;

  const ArtemisCheckBox(
      {Key? key,
      this.suffix,
      this.padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 2),
      this.checkBoxAtEnd = false,
      this.disabled = false,
      required this.onChanged,
      required this.value,
      this.labelWidget,
      this.activeColor = ArtemisColors.lightIshBlue,
      required this.label})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: TextButton.styleFrom(padding: padding ?? EdgeInsets.all(4)),
        onPressed: () {
          onChanged(!value);
        },
        child: checkBoxAtEnd
            ? Row(
                children: [
                  labelWidget ??
                      Text(
                        "$label",
                        style: TextStyle(
                            fontSize: 16,
                            color: disabled
                                ? ArtemisColors.brownGrey.withOpacity(0.8)
                                : value
                                    ? (activeColor)
                                    : ArtemisColors.texts),
                      ),
                  Spacer(),
                  SizedBox(
                    width: 20,
                    child: Checkbox(
                      activeColor: activeColor,
                      value: value,
                      onChanged: onChanged,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(5)),
                    ),
                  ),
                ],
              )
            : Row(
                children: [
                  SizedBox(
                    width: 20,
                    child: Checkbox(
                      activeColor: activeColor,
                      value: value,
                      onChanged: onChanged,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(5)),
                    ),
                  ),
                  SizedBox(width: 8),
                  labelWidget ??
                      Text(
                        "$label",
                        style: TextStyle(
                            fontSize: 16,
                            color: disabled
                                ? ArtemisColors.brownGrey.withOpacity(0.8)
                                : value
                                    ? activeColor
                                    : ArtemisColors.texts),
                      )
                ],
              ));
  }
}
