import 'dart:math';
import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'Consts.dart';
import 'artemis_icons_icons.dart';

class ArtemisDropDown<T> extends StatelessWidget {
  final DropdownSearchItemAsString<T> itemAsString;
  final Color Function(T)? itemToColor;
  final List<T>? items;
  final ValueChanged<T?>? onChanged;
  final T? selectedItem;
  final String? label;
  final bool showClearButton;
  final bool supportNull;
  final bool locked;
  final bool required;
  final bool showSearch;
  final bool showSelected;
  final String? hint;
  final AutovalidateMode? autoValidateMode;

  final FormFieldValidator<T>? validator;

  const ArtemisDropDown(
      {Key? key,
      required this.itemAsString,
      this.locked = false,
      this.showSearch = false,
      this.showSelected = false,
      this.required = false,
      this.itemToColor,
      required this.label,
      this.items,
      this.autoValidateMode,
      this.validator,
      this.hint,
      this.onChanged,
      this.selectedItem,
      this.showClearButton = true,
      this.supportNull = true})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    ThemeData theme = Theme.of(context);
    return DropdownSearch<T>(

      enabled: !locked,
      clearButtonProps: ClearButtonProps(
        isVisible: showClearButton,
        icon: Icon(locked ? ArtemisIcons.lock : Icons.clear),
      ),
      validator: validator,
      autoValidateMode: autoValidateMode,
      onChanged: onChanged,
      selectedItem: selectedItem,
      dropdownDecoratorProps: DropDownDecoratorProps(
        dropdownSearchDecoration: (required ? Styles.dropDownStyleRequired : Styles.dropDownStyle).copyWith(
          labelStyle: TextStyle(fontSize: 16, height: selectedItem == null ? 1 : 0.8),
          labelText: label,
          hintText: hint,
          contentPadding: EdgeInsets.symmetric(
            horizontal: 8,
            vertical: 0,
          ),
        ),
      ),
      items: items ?? [],

      popupProps: PopupProps.menu(
        showSearchBox: showSearch,
        showSelectedItems: showSelected,
        searchDelay: Duration(milliseconds: 0),
        searchFieldProps: TextFieldProps(
          autofocus: true,

          decoration: InputDecoration(
            isDense: true,
            prefixIcon: Icon(ArtemisIcons.search,size: 14),
            border: OutlineInputBorder(

            ),
          )
        ),
        emptyBuilder: (c, i) => Container(
          padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
          child: Center(child: Text("No Option", style: theme.textTheme.headline6!.copyWith(color: ArtemisColors.brownGrey))),
        ),
        itemBuilder: (c, item, i) {
          String main = itemAsString(item);
          String sub = "";
          if (itemAsString(item).contains("(") && itemAsString(item).contains(")")) {
            main = itemAsString(item).split("(")[0];
            sub = "(" + itemAsString(item).split("(")[1];
          }
          return Column(
            children: [
              Container(
                padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
                child: Center(
                    child: RichText(
                  text: TextSpan(children: [
                    TextSpan(
                        text: "$main",
                        style: TextStyle(
                            fontSize: 16, color: itemToColor == null || item == null ? ArtemisColors.black : itemToColor!(item))),
                    TextSpan(text: "$sub", style: TextStyle(fontSize: 12, color: ArtemisColors.brownGrey)),
                  ]),
                )),
              ),
              Divider(height: 3)
            ],
          );
        },
        constraints:  BoxConstraints(
          maxHeight: (showSearch?40:0) + (max(min(((items ?? []).length), 5), 1)) * 35 + 10,
        ),
      ),

      // clearButtonBuilder: !locked
      //     ? null
      //     : (c) => GestureDetector(
      //           child: Icon(ArtemisIcons.lock),
      //           onTap: () {
      //             if (onChanged != null) {
      //               onChanged!(null);
      //             }
      //           },
      //         ),
      // emptyBuilder: (c, i) => Container(
      //       padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
      //       child: Center(
      //           child: Text("No Option",
      //               style: theme.textTheme.headline6!
      //                   .copyWith(color: ArtemisColors.brownGrey))),
      //     ),
      // dropdownButtonBuilder: (c) => Container(height: 40),
      // maxHeight: (max(min(((items ?? []).length), 5), 1)) * 35 + 10,
      // dropdownSearchDecoration:
      //     (required ? Styles.dropDownStyleRequired : Styles.dropDownStyle)
      //         .copyWith(
      //   labelStyle:
      //       TextStyle(fontSize: 16, height: selectedItem == null ? 1 : 0.8),
      //   contentPadding: EdgeInsets.symmetric(
      //     horizontal: 8,
      //     vertical: 0,
      //   ),
      // ),
      // clearButtonBuilder: (c)=>Container(),
      itemAsString: (item) {
        String main = itemAsString(item);
        return main;
      },
      // popupItemBuilder: (c, item, i) {
      //   String main = itemAsString(item);
      //   String sub = "";
      //   if (itemAsString(item).contains("(") &&
      //       itemAsString(item).contains(")")) {
      //     main = itemAsString(item).split("(")[0];
      //     sub = "(" + itemAsString(item).split("(")[1];
      //   }
      //   return Column(
      //     children: [
      //       Container(
      //         padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
      //         child: Center(
      //             child: RichText(
      //           text: TextSpan(children: [
      //             TextSpan(
      //                 text: "$main",
      //                 style: TextStyle(
      //                     fontSize: 16,
      //                     color: itemToColor == null || item == null
      //                         ? ArtemisColors.black
      //                         : itemToColor!(item))),
      //             TextSpan(
      //                 text: "$sub",
      //                 style: TextStyle(
      //                     fontSize: 12, color: ArtemisColors.brownGrey)),
      //           ]),
      //         )),
      //       ),
      //       Divider(height: 3)
      //     ],
      //   );
      // },

      // mode: Mode.MENU,
      // items: items,
      // label:label==null?null: " $label",
      // hint:hint ,
    );
  }

// @override
// Widget build(BuildContext context) {
//   ThemeData theme = Theme.of(context);
//   return DropdownSearch<T>(
//       enabled: !locked,
//       showClearButton: showClearButton,
//       dropdownBuilderSupportsNullItem: supportNull,
//       dropdownBuilder: (c, s, i) {
//         String main = i;
//         String sub = "";
//         if (i.contains("(") && i.contains(")")) {
//           main = i.split("(")[0];
//           sub = "(" + i.split("(")[1];
//         }
//         return Padding(
//           padding: const EdgeInsets.only(left: 12),
//           child: RichText(
//             text: TextSpan(children: [
//               TextSpan(
//                   text: "$main",
//                   style: TextStyle(
//                       fontSize: 16,
//                       color: itemToColor == null || s == null
//                           ? ArtemisColors.black
//                           : itemToColor!(s))),
//               TextSpan(
//                   text: "$sub",
//                   style: TextStyle(
//                       fontSize: 12, color: ArtemisColors.brownGrey)),
//             ]),
//           ),
//         );
//       },
//       clearButtonBuilder: !locked
//           ? null
//           : (c) => GestureDetector(
//         child: Icon(ArtemisIcons.lock),
//         onTap: () {
//           if (onChanged != null) {
//             onChanged!(null);
//           }
//         },
//       ),
//       emptyBuilder: (c, i) => Container(
//         padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
//         child: Center(
//             child: Text("No Option",
//                 style: theme.textTheme.headline6!
//                     .copyWith(color: ArtemisColors.brownGrey))),
//       ),
//       dropdownButtonBuilder: (c) => Container(height: 40),
//       maxHeight: (max(min(((items ?? []).length), 5), 1)) * 35 + 10,
//       dropdownSearchDecoration:
//       (required ? Styles.dropDownStyleRequired : Styles.dropDownStyle)
//           .copyWith(
//         labelStyle:
//         TextStyle(fontSize: 16, height: selectedItem == null ? 1 : 0.8),
//         contentPadding: EdgeInsets.symmetric(
//           horizontal: 8,
//           vertical: 0,
//         ),
//       ),
//       // clearButtonBuilder: (c)=>Container(),
//       itemAsString: (item) {
//         String main = itemAsString(item);
//         return main;
//       },
//       popupItemBuilder: (c, item, i) {
//         String main = itemAsString(item);
//         String sub = "";
//         if (itemAsString(item).contains("(") &&
//             itemAsString(item).contains(")")) {
//           main = itemAsString(item).split("(")[0];
//           sub = "(" + itemAsString(item).split("(")[1];
//         }
//         return Column(
//           children: [
//             Container(
//               padding: EdgeInsets.symmetric(horizontal: 4, vertical: 5),
//               child: Center(
//                   child: RichText(
//                     text: TextSpan(children: [
//                       TextSpan(
//                           text: "$main",
//                           style: TextStyle(
//                               fontSize: 16,
//                               color: itemToColor == null || item == null
//                                   ? ArtemisColors.black
//                                   : itemToColor!(item))),
//                       TextSpan(
//                           text: "$sub",
//                           style: TextStyle(
//                               fontSize: 12, color: ArtemisColors.brownGrey)),
//                     ]),
//                   )),
//             ),
//             Divider(height: 3)
//           ],
//         );
//       },
//       mode: Mode.MENU,
//       items: items,
//       label:label==null?null: " $label",
//       hint:hint ,
//       onChanged: onChanged,
//       selectedItem: selectedItem);
// }
}
