import 'package:flutter/material.dart';

import 'Consts.dart';

class ArtemisSwitch extends StatelessWidget {
  final ValueChanged<dynamic> onChanged;
  final bool disabled;
  final bool value;
  final bool switchAtEnd;
  final String label;
  final Widget? suffix;
  final Widget? labelWidget;
  final Color activeColor;
  final EdgeInsetsGeometry? padding;

  const ArtemisSwitch(
      {Key? key,
      this.suffix,
      this.padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 2),
      this.switchAtEnd = false,
      this.disabled = false,
      required this.onChanged,
      required this.value,
      this.labelWidget,
      this.activeColor = ArtemisColors.primary,
      required this.label})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: TextButton.styleFrom(padding: padding ?? EdgeInsets.all(4)),
        onPressed: () {
          onChanged(!value);
        },
        child: switchAtEnd
            ? Row(
                children: [
                  labelWidget ??
                      Text(
                        "$label",
                        style: TextStyle(
                            fontSize: 16,
                            color: disabled
                                ? ArtemisColors.brownGrey.withOpacity(0.8)
                                : value
                                    ? activeColor
                                    : ArtemisColors.texts),
                      ),
                  Spacer(),
                  Switch(
                    activeColor: activeColor,
                    value: value,
                    onChanged: onChanged,
                  ),
                ],
              )
            : Row(
                children: [
                  Switch(
                    activeColor: activeColor,
                    value: value,
                    onChanged: onChanged,
                  ),
                  labelWidget ??
                      Text(
                        "$label",
                        style: TextStyle(
                            fontSize: 16,
                            color: disabled
                                ? ArtemisColors.brownGrey.withOpacity(0.8)
                                : value
                                    ? activeColor
                                    : ArtemisColors.texts),
                      )
                ],
              ));
  }
}
