import 'package:flutter/cupertino.dart';
import 'package:intl/intl.dart';

String getFormattedNumber(String? value) {
  return double.tryParse("${value ?? ""}") == null
      ? "${value ?? ""}"
      : NumberFormat.decimalPattern().format(double.tryParse("${value ?? ""}"));
}

extension format on num? {
  String get formattedStr {
    return double.tryParse("${this ?? ""}") == null
        ? "${this ?? ""}"
        : NumberFormat.decimalPattern()
            .format(double.tryParse("${this ?? ""}"));
  }

  String get str {
    return "${this ?? ""}";
  }
}

extension parse on String? {
  int? get tryInt {
    return int.tryParse((this ?? "").replaceAll(",", ""));
  }

  double? get tryDouble {
    return double.tryParse((this ?? "").replaceAll(",", ""));
  }

  String? get formattedInt {
    return this.tryInt == null ? this : this.tryInt.formattedStr;
  }

  Duration? get tryDuration {
    if (this == null || !this!.contains(":")) {
      return null;
    } else {
      List<String> splitted = this!.split(":");
      if (splitted.any((element) => int.tryParse(element) == null)) {
        return null;
      } else {
        if (splitted.length == 2) {
          return Duration(
              hours: int.tryParse(splitted[0])!,
              minutes: int.tryParse(splitted[1])!);
        } else if (splitted.length == 3) {
          return Duration(
              hours: int.tryParse(splitted[0])!,
              minutes: int.tryParse(splitted[1])!,
              seconds: int.tryParse(splitted[2])!);
        } else {
          return null;
        }
      }
    }
  }

  Color? get tryHexColor {
    if (this == null) return null;
    String hexColor = this!.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    int? hex = int.tryParse(hexColor, radix: 16);
    if (hex == null) return null;
    Color? c = Color(hex);

    return c;
  }
}

extension fromat on DateTime? {
  String get toddMMMEEE {
    return this == null ? "" : DateFormat("ddMMM, EEE").format(this!);
  }

  String get toddMMM {
    return this == null ? "" : DateFormat("dd MMM").format(this!);
  }

  String get toyyyyMMdd {
    return this == null ? "" : DateFormat("yyyy-MM-dd").format(this!);
  }
}

extension fromatStr on Duration? {
  String? get formatHHMMSS {
    if (this == null) return null;
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitMinutes = twoDigits(this!.inMinutes.remainder(60));
    String twoDigitSeconds = twoDigits(this!.inSeconds.remainder(60));
    return "${twoDigits(this!.inHours)}:$twoDigitMinutes:$twoDigitSeconds";
  }

  String? get formatHHMM {
    if (this == null) return null;
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitMinutes = twoDigits(this!.inMinutes.remainder(60));
    return "${twoDigits(this!.inHours)}:$twoDigitMinutes";
  }
}
